package hu.uniobuda.nik;

import java.util.ArrayList;
import java.util.List;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Paint.Style;
import android.util.AttributeSet;
import android.view.View;

public class Graph extends View {

	// Const -----------------------------
	private final static int MAX_VALUES = 50;
	
	// Variable --------------------------
	private List<Float> values;
	private Paint paint;
	private Path line;
	
	// Construct --------------------------
	public Graph(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		init();
	}
	public Graph(Context context, AttributeSet attrs) {
		super(context, attrs);
		init();
	}
	public Graph(Context context) {
		super(context);
		init();
	}	
	private void init(){		
		this.values = new ArrayList<Float>();
		for(int i = 0; i < MAX_VALUES; i++)
			this.values.add(0.0f);
		
		this.line = new Path();
		this.paint = new Paint();
		this.paint.setColor(Color.WHITE);
		this.paint.setStyle(Style.STROKE);
		this.paint.setStrokeWidth(2);
		this.paint.setAntiAlias(true);
	}
	
	
	
	// Public methods --------------------
	public void addValue(float value){
		// FIFO
		this.values.remove(0);
		this.values.add(value);
		invalidate();
	}
	
	// onDraw -----------------------------	
	@Override
	protected void onDraw(Canvas canvas) {
		super.onDraw(canvas);
		
		int width = getWidth();
		int height = getHeight();
		
		int width_step = width / values.size();
		int height_step = width_step;
		
		int height_offset = height >> 1;
				
		line.reset();
		line.moveTo(0, (values.get(0) * height_step) + height_offset);
		
		// 1-től, mert az elsőt már kirajzoltuk
		for(int i = 1; i < values.size(); i++){
			
			line.lineTo(
						width_step * i,
						(height_step * values.get(i)) + height_offset
					);
			
		}
		
		// zárt alakzatot jelent
		//line.close();
		
		canvas.drawPath(line, paint);
	}

}
